==> CRM64Pro-0.14.0-docs.zip: CRM64Pro-0.14.0-docs/html/group___cursor_m.js <==
var group___cursor_m =
[
    [ "CRM64Pro::Cursor", "class_c_r_m64_pro_1_1_cursor.html", [
      [ "info", "class_c_r_m64_pro_1_1_cursor.html#ac8f32555a5e760b4b01df68ca7c55c66", null ],
      [ "getName", "class_c_r_m64_pro_1_1_cursor.html#a559e8ab6598072118a62660fe1fb39f5", null ],
      [ "getID", "class_c_r_m64_pro_1_1_cursor.html#ab138c5a44c1d20566cd50932ce5992da", null ],
      [ "assignImage", "class_c_r_m64_pro_1_1_cursor.html#a6da04be5f5ac7af90dcd5ef5704c13cf", null ],
      [ "getImage", "class_c_r_m64_pro_1_1_cursor.html#aa87c424031160be8e8cc20571c10b458", null ],
      [ "build", "class_c_r_m64_pro_1_1_cursor.html#a413475e784f072975e633bb859935c8c", null ],
      [ "setHotSpot", "class_c_r_m64_pro_1_1_cursor.html#a626aa160cbe8ccc19b2628083ff41f22", null ],
      [ "getHotSpot", "class_c_r_m64_pro_1_1_cursor.html#a6f6aa0f90157ebf03636d99d924bd1c1", null ],
      [ "save", "class_c_r_m64_pro_1_1_cursor.html#ab8a6d157a31bf12001820f7f048db555", null ],
      [ "save", "class_c_r_m64_pro_1_1_cursor.html#a4d42f4325306c9aa541fec81eb99b786", null ]
    ] ],
    [ "CRM64Pro::CursorMgr", "class_c_r_m64_pro_1_1_cursor_mgr.html", [
      [ "info", "class_c_r_m64_pro_1_1_cursor_mgr.html#ae3b482c2f7f61b4e6b29480e107d522d", null ],
      [ "create", "class_c_r_m64_pro_1_1_cursor_mgr.html#a95b31d2695c986eb370c6b35321d00ce", null ],
      [ "close", "class_c_r_m64_pro_1_1_cursor_mgr.html#a5f02ccbc4e9c257956b5fb092faccdc8", null ],
      [ "getCount", "class_c_r_m64_pro_1_1_cursor_mgr.html#a43458fd03c13f51a304d075fc934f674", null ],
      [ "setName", "class_c_r_m64_pro_1_1_cursor_mgr.html#a18547983f01a24f7a6b11f29e1576efc", null ],
      [ "get", "class_c_r_m64_pro_1_1_cursor_mgr.html#ad837d3e9ab7b1b4db30dda38f887dc23", null ],
      [ "select", "class_c_r_m64_pro_1_1_cursor_mgr.html#a22353c114c06e110419bd66d9e2c9522", null ],
      [ "getSelect", "class_c_r_m64_pro_1_1_cursor_mgr.html#ae7ed75e3918d2b2f7d2cb979c4e51fe2", null ],
      [ "show", "class_c_r_m64_pro_1_1_cursor_mgr.html#a80b7738b1228c662e0d0c668cba8a60c", null ],
      [ "hide", "class_c_r_m64_pro_1_1_cursor_mgr.html#abf72feb42eabd6a26f55297ae38b3af7", null ],
      [ "status", "class_c_r_m64_pro_1_1_cursor_mgr.html#a9955e00da3eb78cf130dd0a7c1c7c968", null ],
      [ "setPosition", "class_c_r_m64_pro_1_1_cursor_mgr.html#a2fb3b6927d18a69fa0aec0848ea49a6d", null ],
      [ "getX", "class_c_r_m64_pro_1_1_cursor_mgr.html#ad94fe9f65acaf0d99fe81c43d2a2ee64", null ],
      [ "getY", "class_c_r_m64_pro_1_1_cursor_mgr.html#a15e5dc2b05bdfb495b93462ad9434182", null ],
      [ "getButtons", "class_c_r_m64_pro_1_1_cursor_mgr.html#ad2d3497d8a8ae886deb71b630d812586", null ],
      [ "getButtonsPrev", "class_c_r_m64_pro_1_1_cursor_mgr.html#a0ce5769e0c9670f6bca8ae79a857c4e1", null ],
      [ "getFocus", "class_c_r_m64_pro_1_1_cursor_mgr.html#ab053980cc4fdef7c78390e72b6826fbc", null ],
      [ "child", "class_c_r_m64_pro_1_1_cursor_mgr.html#a735fa52353010823b978e1ba131365a2", null ],
      [ "load", "class_c_r_m64_pro_1_1_cursor_mgr.html#a939a74d5db00c93332c375290d4eb986", null ],
      [ "load", "class_c_r_m64_pro_1_1_cursor_mgr.html#acf027025c4d4f2814b53572e9d3bd62e", null ],
      [ "remove", "class_c_r_m64_pro_1_1_cursor_mgr.html#ab79f3e170e1854372422bc5eff43a678", null ],
      [ "exist", "class_c_r_m64_pro_1_1_cursor_mgr.html#ae882b98c6aae6effc228f514976b3afe", null ],
      [ "exist", "class_c_r_m64_pro_1_1_cursor_mgr.html#ae39193ddfadfdec7798bc1889c6cf939", null ]
    ] ]
];

==> CRM64Pro-0.15.0-docs.zip: CRM64Pro-0.15.0-docs/html/group___cursor_m.js <==
var group___cursor_m =
[
    [ "CRM64Pro::Cursor", "class_c_r_m64_pro_1_1_cursor.html", [
      [ "info", "class_c_r_m64_pro_1_1_cursor.html#ac8f32555a5e760b4b01df68ca7c55c66", null ],
      [ "getName", "class_c_r_m64_pro_1_1_cursor.html#a559e8ab6598072118a62660fe1fb39f5", null ],
      [ "getID", "class_c_r_m64_pro_1_1_cursor.html#ab138c5a44c1d20566cd50932ce5992da", null ],
      [ "assignImage", "class_c_r_m64_pro_1_1_cursor.html#a6da04be5f5ac7af90dcd5ef5704c13cf", null ],
      [ "getImage", "class_c_r_m64_pro_1_1_cursor.html#aa87c424031160be8e8cc20571c10b458", null ],
      [ "build", "class_c_r_m64_pro_1_1_cursor.html#a413475e784f072975e633bb859935c8c", null ],
      [ "setHotSpot", "class_c_r_m64_pro_1_1_cursor.html#a626aa160cbe8ccc19b2628083ff41f22", null ],
      [ "getHotSpot", "class_c_r_m64_pro_1_1_cursor.html#a6f6aa0f90157ebf03636d99d924bd1c1", null ],
      [ "save", "class_c_r_m64_pro_1_1_cursor.html#ab8a6d157a31bf12001820f7f048db555", null ],
      [ "save", "class_c_r_m64_pro_1_1_cursor.html#a4d42f4325306c9aa541fec81eb99b786", null ]
    ] ],
    [ "CRM64Pro::CursorMgr", "class_c_r_m64_pro_1_1_cursor_mgr.html", [
      [ "info", "class_c_r_m64_pro_1_1_cursor_mgr.html#ae3b482c2f7f61b4e6b29480e107d522d", null ],
      [ "create", "class_c_r_m64_pro_1_1_cursor_mgr.html#a95b31d2695c986eb370c6b35321d00ce", null ],
      [ "close", "class_c_r_m64_pro_1_1_cursor_mgr.html#a5f02ccbc4e9c257956b5fb092faccdc8", null ],
      [ "getCount", "class_c_r_m64_pro_1_1_cursor_mgr.html#a43458fd03c13f51a304d075fc934f674", null ],
      [ "setName", "class_c_r_m64_pro_1_1_cursor_mgr.html#a18547983f01a24f7a6b11f29e1576efc", null ],
      [ "get", "class_c_r_m64_pro_1_1_cursor_mgr.html#ad837d3e9ab7b1b4db30dda38f887dc23", null ],
      [ "select", "class_c_r_m64_pro_1_1_cursor_mgr.html#a22353c114c06e110419bd66d9e2c9522", null ],
      [ "getSelect", "class_c_r_m64_pro_1_1_cursor_mgr.html#ae7ed75e3918d2b2f7d2cb979c4e51fe2", null ],
      [ "show", "class_c_r_m64_pro_1_1_cursor_mgr.html#a80b7738b1228c662e0d0c668cba8a60c", null ],
      [ "hide", "class_c_r_m64_pro_1_1_cursor_mgr.html#abf72feb42eabd6a26f55297ae38b3af7", null ],
      [ "status", "class_c_r_m64_pro_1_1_cursor_mgr.html#a661cdee902d92172cc744935e56edd70", null ],
      [ "setPosition", "class_c_r_m64_pro_1_1_cursor_mgr.html#a2fb3b6927d18a69fa0aec0848ea49a6d", null ],
      [ "getX", "class_c_r_m64_pro_1_1_cursor_mgr.html#ad94fe9f65acaf0d99fe81c43d2a2ee64", null ],
      [ "getY", "class_c_r_m64_pro_1_1_cursor_mgr.html#a15e5dc2b05bdfb495b93462ad9434182", null ],
      [ "getButtons", "class_c_r_m64_pro_1_1_cursor_mgr.html#ad2d3497d8a8ae886deb71b630d812586", null ],
      [ "getButtonsPrev", "class_c_r_m64_pro_1_1_cursor_mgr.html#a0ce5769e0c9670f6bca8ae79a857c4e1", null ],
      [ "getFocus", "class_c_r_m64_pro_1_1_cursor_mgr.html#ab053980cc4fdef7c78390e72b6826fbc", null ],
      [ "child", "class_c_r_m64_pro_1_1_cursor_mgr.html#a735fa52353010823b978e1ba131365a2", null ],
      [ "load", "class_c_r_m64_pro_1_1_cursor_mgr.html#a939a74d5db00c93332c375290d4eb986", null ],
      [ "load", "class_c_r_m64_pro_1_1_cursor_mgr.html#acf027025c4d4f2814b53572e9d3bd62e", null ],
      [ "loadFromBuffer", "class_c_r_m64_pro_1_1_cursor_mgr.html#a3947e5ab2dc4ca312b4ea13fc69b7abd", null ],
      [ "remove", "class_c_r_m64_pro_1_1_cursor_mgr.html#ab79f3e170e1854372422bc5eff43a678", null ],
      [ "exist", "class_c_r_m64_pro_1_1_cursor_mgr.html#ae882b98c6aae6effc228f514976b3afe", null ],
      [ "exist", "class_c_r_m64_pro_1_1_cursor_mgr.html#ae39193ddfadfdec7798bc1889c6cf939", null ]
    ] ]
];
